# CoolMasterNet/CooLinkNet Zone Driver

![image logo](./doc_image.PNG)

This driver represents an HVAC zone connected to the CoolMasterNet or CooLinkNet system.
The driver will not function unless the gateway driver is in the project and available.

## Connections

### CoolMasterNet Link
The driver will automatically bind to a gateway driver in your project.

You should check that it has bound to the correct device by checking the Connections tab.

### Supplementary Heating
Relay connection that controls supplementary heating system.

### Temperature
Receive/provide temperature from/to remote source/consumer.


## Customisation
Different manufacturers and models have different capabilities.

You can customise the UI displayed to the user by editing the properties of the driver.

If all zones have the same capabilities you can configure one zone and then use the Action tab to send this configuration to the other zones in the project.


## Properties

### Setpoint Temperature Offset
The offset value for the Setpoint temperature that will display on a thermostat or UI.

This value does not affect setpoint temperature on the CoolAutomation device.

Offset can take values in range -5 to 5 in Kelvin (K) units. 1K absolute Kelvin equals 1C and 1.8F.

### Setpoint Temperature Min/Max C/F
Those properties set minimal and maximal setpoint temperature for Fahrenheit and Celsius scale.

Minimal values are from range 5 - 20 for [C] and from 41 - 68 for [F].

Maximal values are from range 25 - 50 for [C] and from 77 - 122 for [F].

### Setpoint Temperature Resolution
Use this property to change step of Setpoint Temperature change. Available values are:

- Min [0.1C/0.2F] - Fahrenheit scale resolution is limited to 0.2, so if you select Min, Celsius resolution will be 0.1 but when changed to Fahrenheit it will be 0.2.
- 0.2
- 0.5
- 1
- 2
- 5

>**NOTE:** Because of differences in Control4 and CoolAutomation scale conversion algorithm, calculation error may occur on systems using 0.2 Fahrenheit.

### Display Temperature Resolution
Use this property to change resolution of Current Temperature value. Available values are:

- Min [0.1C/0.2F] - Fahrenheit scale resolution is limited to 0.2, so if you select Min, Celsius resolution will be 0.1 but when changed to Fahrenheit it will be 0.2.
- 0.2
- 0.5
- 1
- 2
- 5

>**NOTE:** Because of differences in Control4 and CoolAutomation scale conversion algorithm, calculation error may occur on systems using 0.2 Fahrenheit.

### CoolMasterNet Line

The CoolMasterNet has seven bus lines and the CooLinkNet has four bus lines available for various HVAC systems.

Use this property to choose the line on which this device is located.

The default is L1 (line 1). The CoolMasterNet Line is provided by the HVAC engineer.

### Zone ID

This is the ID of the indoor HVAC unit.

The format of this depends on the manufacturer.

The available devices on your system will be shown on the screen of the CoolMasterNet if it has been correctly configured.

The ID is provided to you by the HVAC engineer.

When you enter the ID within 30 seconds you should see the message Received Zone Information in the Driver Information box.

This confirms that the details of the HVAC zone have been received by the driver and it should operate correctly.

For a single device connected to a CooLinkNet system the ZoneID is usually 000.

### Available HVAC Modes

This property should be edited to match the modes available for this zone. The letters correspond to the following modes:

* h &#8594; Heat
* c &#8594; Cool
* a &#8594; Auto
* f &#8594; Fan only
* d &#8594; Dry

Delete the letters corresponding to any mode that the unit being controlled does not support.

### Fan Speeds

This property should be edited to match the fan speeds available for this zone.
The letters correspond to the following speeds:

* v &#8594; Very Low
* l &#8594; Low
* m &#8594; Medium
* h &#8594; High
* t &#8594; Top
* a &#8594; Auto

Delete the letters corresponding to any mode that the unit being controlled does not support.

### Swing Choices

If the indoor unit has the ability to swing the vanes then enter the modes supported here.

The acceptable values are:

* h &#8594; Horizontal
* v &#8594; Vertical
* 3 &#8594; 30 degrees
* 4 &#8594; 45 degrees
* 6 &#8594; 60 degrees
* a &#8594; Auto

If the unit does not support swing then delete all the letters and this option will not be shown on the UI.

### Ventilation Unit Choices
If the zone has an external ventilation unit then this property allows you to select the available modes for that unit.

If no unit is present then delete all of the choices.

* a &#8594; Auto Mode
* b &#8594; Bypass
* x &#8594; Heat Exchange
* n &#8594; Normal
* l &#8594; Low Fan
* L &#8594; Low Fan with Fresh Up
* h &#8594; High Fan
* H &#8594; High Fan with Fresh Up
* s &#8594; Super High Fan
* t &#8594; Top Fan
* A &#8594; Auto Fan

### Water Heater Choices

If the unit is also capable of heating hot water you can define the choices available to the user here.

If the unit does not have hot water capabilities then delete all of the choices.

* h &#8594; Heat
* e &#8594; Eco
* w &#8594; Hot
* a &#8594; Auto

### Change Filter Snooze Interval (Days)
This driver will show “Change Filter” reminder regarding cleaning of the filter.

It is also possible to reset this reminder and hide the “Change Filter” message.

The “Change Filter Snooze Interval” property specifies the number of days after which the filter reminder is checked again.

**NOTE: The “Change Filter” message can also appear when director is restarted or when the “Zone ID” property is changed, regardless of the Change Filter Snooze Interval.**

### Number of ON/OFF Zones

Some HVAC systems have one main unit which shares data withc many dependent units.

This option allows to select number of dependend units that could be controlled from extras in UI.

After selectring number of dependent units, Zone ID and Zone Name properties should appear regarding selcted number.

Maximal number of On/Off Zones is 9.

When decrease On/Off Zone Number properties regarding Zone Name and Zone ID will dissapear from bigger to smaller number (ex. from 3 to 1).

All On/Off zones are related to selected line in CoolMasterNet Line property.

### On/Off Zone # ID

This property allows to select Zone ID of a dependent unit.

Corresponding Zone could be controlled in UI extras using ON and OFF commands.

On/Off Zone ID property can be changed when system is active and that change will be updated in extras.

Please ensure that correct ID is entered.

### On/Off Zone # Name


This property allows to enter name of the On/Off zone. The name will appear in UI extras. It is possible to change the Zone Name and that change will be updated in extras.


## Supplementary Heating Feature

If a zone has a supplementary heating system such as underfloor heating then the driver enables you to control this system via a relay connection.

You will need to a relay to control the supplementary system which depending on the system.

You need to check the requirements of the system with the manufacturer.

Any relay which can be controlled by Control4 from the relay on a controller to a high power zigbee relay can potentially be used.

You need to make a connection between the CoolMasterNet zone driver and the relay you are using to control the supplementary heating system in the zone.

Supplementary Heating property value is in Kelvin units (+1K on scale equals +1C and +1.8F).

There are some important points to consider:

* You must choose the correct type and rating of relay to control the zone. This may be high or low voltage.
* The driver will only use and control the supplementary heating system when the zone is in Heat mode. In any other mode (including Auto ) the supplementary heating will be turned off.
* You should not fit any additional thermostat or physical control for the supplementary heating system in this zone.
* You must supply and offset and de-bounce time for control.

### Underfloor (Radiant) Only Mode

The driver can also provide a radiant only mode.

If this mode is selected then the HVAC system connected to the CoolMaster will be turned Off.

The room temperature from the HVAC system will be used to switch the connected relay to control the underfloor or radiant system.

If this mode is not applicable in your installation be sure to remove the u option from the available HVAC modes.

If the setup uses the HVAC system only for cooling then please use the specific driver for this from the Composer database.

### Debounce Minutes

Some heating systems should not be switched on and off in quick succession.

It is also inefficient to do so.

This option ensures that the state of the heating system does not cycle more than once in the time period specified.


## Actions

### Send Capabilities to Other Zones

If all of the zones on the HVAC system have the same capabilities this action enables you to set up one zone on the system and then send the capabilities to all the other zones.

Ensure that you have added all the zone thermostat drivers into the project and connected them to the gateway driver.

Then select this action to transfer the properties from Available HVAC Modes to Water Heater Choices to the other drivers.

### Send C4 Settings to Zone

This will force the driver to send all its current settings to the HVAC zone.


## Custom Programming

* Events &#8594; Standard Thermostat Events are supported by the driver. The driver also supports “Change Filter Reminder” event for cleaning the filters. This event is fired when the “Change Filter” message reappears on the Navigator (for more details, refer to “Change Filter Snooze Interval (Days)”). The driver supports "On/Off Zone State Changed" event which fires when any of On/Off Zones changes state.
* Commands &#8594; Standard Thermostat Commands are supported by the driver. The driver also supports "Set Zone ON" , "Set Zone OFF" that set On/Off Zone state and "Send HVAC Mode" which sends current HVAC mode of the main zone to On/Off Zones. If needed, one Zone can "broadcast" HVAC mode to other Zones via "Set one available HVAC mode" command which sets HVAC mode of the main zone as only available mode of the secondary zone.
* Conditionals &#8594; Standard Thermostat Conditionals are supported by the driver. Besides standard conditionals, the driver supports "On/Off Zone is ON" and "On/Off Zone is OFF" conditionals which check if selected On/Off Zone is ON or OFF.
* Schedule &#8594; The end user can set a schedule from any navigator. Schedules are based on Presets that are set under the Temperature tab. Once a Preset is saved, select the Schedule tab. Then add schedules with the "+" symbol in the upper-right hand corner.
**Note: the "+" symbol is not selectable without saved Presets.**
* Hold Modes &#8594; Hold Modes are designed to make Preset Scheduling more flexible. Using Hold Modes end user can delay scheduled Preset for some time or override Preset’s HVAC values The following Hold Modes are supported:
	* Off &#8594; Last scheduled Preset will be active (no hold)
	* 2 Hours &#8594; Hold current values for 2 hours, then revert to last scheduled Preset.
	* Until next &#8594; Overrides current Preset and holds until next scheduled event.
	* Permanent &#8594; Hold given values until you manually change Preset (typically used for 'vacation mode', etc.)
	* Hold until &#8594; Hold current values until specified date and time.
* Device Specific Command
	* Set Zone ON &#8594; Select On/Off Zone that will turn ON if condition is satisfied
	* Set Zone OFF &#8594; Select On/Off Zone that will turn OFF if condition is satisfied

**Note: Hold Modes work only when Preset is active.**


## Support

For support on this driver please contact Control4 technical support or your local Control4 distributor.


## CHANGELOG

**1.3.4** March 2023

* Implement Setpoint and Display resolution properties [DRIV-8636]

**1.3.3 November 2021**

* Fixed locale settings issue [DRIV-6861]
* Added more On/Off zones [DRIV-6877]
* Fixed event and command execution issues

**1.2.9 October 2021**

* Fixed Fan mode change issue [DRIV-6572]
* Added setpoint temperature range property [DRIV-6680]
* Updated translations [DRIV-6804]

**1.2.6 July 2021**

* Added "Send HVAC Mode" and "Set one available HVAC mode" commands [DRIV-6281]
* Fixed bug regarding On/Off zone blocked programming [DRIV-6254]
* Fixed temperature reading and scale conversion offset [DRIV-5918]
* Added On/Off Zone conditional programming (if ON/OFF) [DRIV-6264]
* Added On/Of Zone state chnged event
* Added On/Off Zone programming command option (set zone ON/OFF) [DRIV-6229]
* Added On/Off Zone control in extras. [DRIV-3385]
* Added external temperature sensor and setpoint temperaute offset features. [DRIV-3501]
* Fixed Supplementary Heating will turn off before Supplementary offset is reached. [DRIV-6062]

**1.1.8 February 2019**

* Fix driver crash issue when a schedule event with HVAC mode 'Off' is used.

**1.1.7 December 2017**

* Add "Hold Modes" section.

**1.1.6 December 2017**

* Changed command for Combined Heating and Aux Heating mode from "hhaux" to "hh".

**1.1.5 November 2017**

* Add Snooze Interval for Change Filter Reminder.  Add HVAC Mode fields for Presets.  * Add “Very Low” fan speed.
* Add Combined Heating and Aux Heating mode

**1.1.4 June 2017**

* Support for SDDP and documentation changes.

**1.0.8 March 2015**

* Adds HAux

**1.0.7  November 2015**

* Corrects issue with presets not restoring with 2.8.0

**1.0.6 September 2015**

* Updated translations

**1.0.5  August 2015**

* Added local language translations.

**1.0.4  August 2015**

* Supports L8 selection (USB)

**1.0.3 July 2015**

* Ensures on Set Setpoint Single is shown in custom programming.

**1.0.2 July 2015**

* Corrects issue with Off mode not remaining on UI

**1.0.1 May 2015**

* Adds support for CooLinkNet

**1.0.0 Mar 24 2015**

* Initial release

